@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package MetaCPAN::Client::Request;
 # ABSTRACT: Object used for making requests to MetaCPAN
-$MetaCPAN::Client::Request::VERSION = '2.035000';
+$MetaCPAN::Client::Request::VERSION = '2.036000';
 use Moo;
 use Carp;
 use JSON::MaybeXS qw<decode_json encode_json>;
@@ -156,9 +156,10 @@ sub _build_body {
         ? { match_all => {} }
         : _build_query_rec($args);
 
+    $query = $self->_apply_filters($query, $params);
+
     return +{
         query => $query,
-        $self->_read_filters($params),
         $self->_read_fields($params),
         $self->_read_aggregations($params),
         $self->_read_sort($params)
@@ -206,14 +207,15 @@ sub _read_aggregations {
     return ( aggregations => $aggregations );
 }
 
-sub _read_filters {
+sub _apply_filters {
     my $self   = shift;
+    my $query  = shift;
     my $params = shift;
 
     my $filter = delete $params->{es_filter};
-    is_ref($filter) or return ();
+    is_ref($filter) or return $query;
 
-    return ( filter => $filter );
+    return { bool => { must => [ $filter, $query ] } };
 }
 
 sub _read_sort {
@@ -284,7 +286,7 @@ MetaCPAN::Client::Request - Object used for making requests to MetaCPAN
 
 =head1 VERSION
 
-version 2.035000
+version 2.036000
 
 =head1 ATTRIBUTES
 
